searchData={"items":[{"type":"module","title":"Toolshed","doc":"Making the IEx console friendlier one command at a time\n\nTo use the helpers, run:\n\n    iex> use Toolshed\n\nAdd this to your `.iex.exs` to load automatically.\n\nThe following is a list of helpers:\n\n  * `cat/1`          - print out a file\n  * `cmd/1`          - run a system command and print the output\n  * `date/0`         - print out the current date and time\n  * `dmesg/0`        - print kernel messages (Nerves-only)\n  * `exit/0`         - exit out of an IEx session\n  * `fw_validate/0`  - marks the current image as valid (check Nerves system if supported)\n  * `geo/1`          - print out a rough physical location\n  * `grep/2`         - print out lines that match a regular expression\n  * `hex/1`          - print a number as hex\n  * `history/0`      - print out the IEx shell history\n  * `httpget/2`      - print or download the results of a HTTP GET request\n  * `hostname/0`     - print our hostname\n  * `ifconfig/0`     - print info on network interfaces\n  * `inspect_bits/1` - pretty print numbers in hex, octal, and binary\n  * `load_term!/1`   - load a term that was saved by `save_term!/2`\n  * `log_attach/1`   - send log messages to the current group leader\n  * `log_detach/0`   - stop sending log messages to the current group leader\n  * `lsof/0`         - print out open file handles by OS process\n  * `lsmod/0`        - print out what kernel modules have been loaded (Nerves-only)\n  * `lsusb/0`        - print info on USB devices\n  * `multicast_addresses/0` - print out all multicast addresses\n  * `nslookup/1`     - query DNS to find an IP address\n  * `ping/2`         - ping a remote host\n  * `qr_encode/1`    - create a QR code (requires networking)\n  * `reboot/0`       - reboots gracefully (Nerves-only)\n  * `reboot!/0`      - reboots immediately  (Nerves-only)\n  * `save_value/3`   - save a value to a file as Elixir terms (uses inspect)\n  * `save_term!/2`   - save a term as a binary\n  * `speed_test/1`   - run a simple network speed test\n  * `top/2`          - list out the top processes\n  * `tcping/2`       - check if a host can be reached (like ping, but uses TCP)\n  * `tree/1`         - pretty print a directory tree\n  * `uptime/0`       - print out the current Erlang VM uptime\n  * `uname/0`        - print information about the running system (Nerves-only)\n  * `weather/0`      - get the local weather (requires networking)","ref":"Toolshed.html"},{"type":"function","title":"Toolshed.cat/1","doc":"Reads and prints out the contents of a file","ref":"Toolshed.html#cat/1"},{"type":"function","title":"Toolshed.cmd/1","doc":"Run a command and return the exit code. This function is intended to be run\ninteractively.","ref":"Toolshed.html#cmd/1"},{"type":"function","title":"Toolshed.date/0","doc":"Return the date and time in UTC","ref":"Toolshed.html#date/0"},{"type":"function","title":"Toolshed.dmesg/0","doc":"Print out kernel log messages","ref":"Toolshed.html#dmesg/0"},{"type":"function","title":"Toolshed.exit/0","doc":"Exit the current IEx session","ref":"Toolshed.html#exit/0"},{"type":"function","title":"Toolshed.fw_validate/0","doc":"Validate a firmware image\n\nAll official Nerves Systems automatically validate newly installed firmware.\nFor some systems, it's possible to disable this so that new firmware gets\none chance to boot. If it's not \"validated\" before a reboot, then the device\nreverts to the old firmware.","ref":"Toolshed.html#fw_validate/0"},{"type":"function","title":"Toolshed.geo/1","doc":"Geo-locate this Elixir instance\n\nOptions:\n\n* `:ifname` - Network interface to use (e.g., `\"eth0\"`)\n* `:whenwhere_url` - URL for the whenwhere server to query. Defaults to http://whenwhere.nerves-project.org\n* `:timeout` - Milliseconds to wait for a response. Defaults to 10_000.\n* `:connect_timeout` - Milliseconds to wait for the connection. Defaults to `:timeout` value","ref":"Toolshed.html#geo/1"},{"type":"function","title":"Toolshed.grep/2","doc":"Run a regular expression on a file and print the matching lines.\n\n    iex> grep ~r/video/, \"/etc/mime.types\"\n\nIf colored is enabled for the shell, the matches will be highlighted red.","ref":"Toolshed.html#grep/2"},{"type":"function","title":"Toolshed.hex/1","doc":"Inspect a value with all integers printed out in hex. This is useful for\none-off hex conversions. If you're doing a lot of work that requires\nhexadecimal output, you should consider running:\n\n`IEx.configure(inspect: [base: :hex])`\n\nThe drawback of doing the above is that strings print out as hex binaries.","ref":"Toolshed.html#hex/1"},{"type":"function","title":"Toolshed.history/1","doc":"Print out the IEx shell history\n\nThe default is to print the history from the current group leader, but\nany group leader can be passed in if desired.","ref":"Toolshed.html#history/1"},{"type":"function","title":"Toolshed.hostname/0","doc":"Return the hostname","ref":"Toolshed.html#hostname/0"},{"type":"function","title":"Examples - Toolshed.hostname/0","doc":"iex> hostname\n    \"nerves-1234\"","ref":"Toolshed.html#hostname/0-examples"},{"type":"function","title":"Toolshed.httpget/2","doc":"Perform a HTTP GET request for the specified URL\n\nBy default, the results are printed or you can optionally choose to download\nit to a specific location on the file system.\n\nOptions:\n\n* `:dest` - File path to write the response to. Defaults to printing to the terminal.\n* `:ifname` - Network interface to use (e.g., `\"eth0\"`)\n* `:timeout` - Download timeout. Defaults to 30_000 ms\n* `:verbose` - Display request and response headers. Disabled by default.","ref":"Toolshed.html#httpget/2"},{"type":"function","title":"Toolshed.ifconfig/0","doc":"Print out the network interfaces and their addresses.","ref":"Toolshed.html#ifconfig/0"},{"type":"function","title":"Toolshed.inspect_bits/1","doc":"Pretty prints a number in hex, octal and binary\n\nExample:\n\n```\niex> Toolshed.inspect_bits(123)\nDecimal     : 123\nHexadecimal : 0000_007B\nOctal       : 173\nBinary      : 01111011\n```","ref":"Toolshed.html#inspect_bits/1"},{"type":"function","title":"Toolshed.load_term!/1","doc":"Load an Erlang term from the filesystem.","ref":"Toolshed.html#load_term!/1"},{"type":"function","title":"Examples - Toolshed.load_term!/1","doc":"iex> save_term!({:some_interesting_atom, [\"some\", \"list\"]}, \"/root/some_atom.term\")\n    {:some_interesting_atom, [\"some\", \"list\"]}\n    iex> load_term!(\"/root/some_atom.term\")\n    {:some_interesting_atom, [\"some\", \"list\"]}","ref":"Toolshed.html#load_term!/1-examples"},{"type":"function","title":"Toolshed.log_attach/1","doc":"Attach the current session to the Elixir logger\n\nThis forwards incoming log messages to the terminal. Call `log_detach/0` to\nstop the messages.\n\nBehind the scenes, this uses Erlang's `logger_std_h` and Elixir's log\nformatter. Options include all of the ones from\n[Logger.Formatter](https://hexdocs.pm/logger/main/Logger.Formatter.html#new/1)\nand the ability to set the level.\n\nFor ease of use, here are the common options:\n\n* `:level` - the minimum log level to report. E.g., specify `level: :warning`\n  to only see warnings and errors.\n* `:metadata` - a list of metadata keys to show or `:all`","ref":"Toolshed.html#log_attach/1"},{"type":"function","title":"Toolshed.log_detach/0","doc":"Detach the current session from the Elixir logger","ref":"Toolshed.html#log_detach/0"},{"type":"function","title":"Toolshed.lsmod/0","doc":"Print out the loaded kernel modules\n\nAside from printing out whether the kernel has been tainted, the\nLinux utility of the same name just dump the contents of \"/proc/modules\"\nlike this one.\n\nSome kernel modules may be built-in to the kernel image. To see\nthose, run `cat \"/lib/modules/x.y.z/modules.builtin\"` where `x.y.z` is\nthe kernel's version number.","ref":"Toolshed.html#lsmod/0"},{"type":"function","title":"Toolshed.lsof/0","doc":"List out open files by process\n\nThis is an simple version of lsof that works on Linux and\nNerves. While running the normal version of lsof provides\nmore information, this can be convenient when lsof isn't\neasily available or can't be run due to `:emfile` errors\nfrom starting port processes due to too many files being open..","ref":"Toolshed.html#lsof/0"},{"type":"function","title":"Toolshed.lsusb/0","doc":"Print out information on all of the connected USB devices.","ref":"Toolshed.html#lsusb/0"},{"type":"function","title":"Toolshed.multicast_addresses/0","doc":"List all active multicast addresses\n\nThis lists out multicast addresses by network interface\nsimilar to `ip maddr show`. It currently only works on\nLinux.","ref":"Toolshed.html#multicast_addresses/0"},{"type":"function","title":"Toolshed.nslookup/1","doc":"Lookup the specified hostname in the DNS and print out the addresses.","ref":"Toolshed.html#nslookup/1"},{"type":"function","title":"Examples - Toolshed.nslookup/1","doc":"iex> nslookup \"google.com\"\n    Name:     google.com\n    Address:  172.217.7.238\n    Address:  2607:f8b0:4004:804::200e","ref":"Toolshed.html#nslookup/1-examples"},{"type":"function","title":"Toolshed.ping/2","doc":"Ping an IP address using ICMP.\n\nNOTE: Specifying an `:ifname` only sets the source IP address for the\nconnection. This is only a hint to use the specified interface and not a\nguarantee. For example, if you have two interfaces on the same LAN, the OS\nrouting tables may send traffic out one interface in preference to the one\nthat you want. On Linux, you can enable policy-based routing and add source\nroutes to guarantee that packets go out the desired interface.\n\nOptions:\n\n* `:count` - number of pings to send (defaults to 3)\n* `:identifier` - the identifier to use in the ICMP packets (default is to generate one)\n* `:ifname`  - network interface to use (e.g., \"eth0\")\n* `:timeout` - time in seconds to wait for a host to respond (defaults to 10 seconds)","ref":"Toolshed.html#ping/2"},{"type":"function","title":"Examples - Toolshed.ping/2","doc":"```\niex> ping \"nerves-project.org\"\nResponse from nerves-project.org (185.199.108.153): icmp_seq=0 time=14.908ms\nResponse from nerves-project.org (185.199.108.153): icmp_seq=1 time=9.057ms\nResponse from nerves-project.org (185.199.108.153): icmp_seq=2 time=21.099ms\n\niex> ping \"google.com\", ifname: \"wlp5s0\"\nResponse from google.com (172.217.7.206): icmp_seq=0 time=88.602ms\n```","ref":"Toolshed.html#ping/2-examples"},{"type":"function","title":"Toolshed.poweroff/0","doc":"Helper for gracefully powering off\n\nNot all Nerves devices support powering themselves off. These devices reboot\ninstead.","ref":"Toolshed.html#poweroff/0"},{"type":"function","title":"Toolshed.qr_encode/1","doc":"Generate an ASCII art QR code\n\nSee https://github.com/chubin/qrenco.de for more information.","ref":"Toolshed.html#qr_encode/1"},{"type":"function","title":"Toolshed.reboot/0","doc":"Shortcut to reboot a board. This is a graceful reboot, so it takes some time\nbefore the real reboot.","ref":"Toolshed.html#reboot/0"},{"type":"function","title":"Toolshed.reboot!/0","doc":"Reboot immediately without a graceful shutdown. This is for the impatient.","ref":"Toolshed.html#reboot!/0"},{"type":"function","title":"Toolshed.save_term!/2","doc":"Save an Erlang term to the filesystem for easy loading later\n\nThis function returns the `value` passed in to allow easy piping.","ref":"Toolshed.html#save_term!/2"},{"type":"function","title":"Examples - Toolshed.save_term!/2","doc":"iex> :sys.get_state(MyServer) |> save_term!(\"/root/my_server.term\")\n    # Reboot board\n    iex> :sys.replace_state(&load_term!(\"/root/my_server.term\"))","ref":"Toolshed.html#save_term!/2-examples"},{"type":"function","title":"Toolshed.save_value/3","doc":"Save a value to a file as Elixir terms","ref":"Toolshed.html#save_value/3"},{"type":"function","title":"Examples - Toolshed.save_value/3","doc":"# Save the contents of SystemRegistry to a file\n    iex> SystemRegistry.match(:_) |> save_value(\"/root/sr.txt\")\n    :ok","ref":"Toolshed.html#save_value/3-examples"},{"type":"function","title":"Toolshed.speed_test/1","doc":"Perform a download speed test\n\nCalling this with no options measures the download speed of a small test\nfile. The test file may not be large enough or close enough to you to\nproduce a good measurement. To fix this, pass a `:url` to a better file. To\nchange the default, add the following to your application environment:\n\n```elixir\nconfig :toolshed, speed_test_url: \"http://my_company.com/speed_test_file.bin\"\n```\n\nCommercial users are encouraged to specify their own files to minimize our\nbandwidth costs.\n\nPlease be aware that this function is somewhat simplistic in how it measures\ndownload performance.\n\nOptions:\n\n* `:duration` - Maximum duration in milliseconds (defaults to 5 seconds)\n* `:ifname` - Interface to use (e.g., `\"wwan0\"` or `\"eth0\"`)\n* `:url` - File to download for the test","ref":"Toolshed.html#speed_test/1"},{"type":"type","title":"Toolshed.speed_test_options/0","doc":"Options for speed_test/1","ref":"Toolshed.html#t:speed_test_options/0"},{"type":"function","title":"Toolshed.tcping/2","doc":"Ping an IP address using TCP\n\nThis tries to connect to the remote host using TCP instead of sending an ICMP\necho request like normal ping. This sometimes works better than ping\nif the remote server or any machine in between drops ICMP messages.\n\nOptions:\n\n* `:count` - number of pings to send (defaults to 3)\n* `:ifname` - Specify a network interface to use. (e.g., \"eth0\")\n* `:port` - Which TCP port to try (defaults to 80)","ref":"Toolshed.html#tcping/2"},{"type":"function","title":"Examples - Toolshed.tcping/2","doc":"iex> tcping \"nerves-project.org\"\n    Response from nerves-project.org (185.199.108.153:80): time=4.155ms\n    Response from nerves-project.org (185.199.108.153:80): time=10.385ms\n    Response from nerves-project.org (185.199.108.153:80): time=12.458ms\n\n    iex> tcping \"google.com\", ifname: \"wlp5s0\"\n    Response from google.com (172.217.7.206:80): time=88.602ms","ref":"Toolshed.html#tcping/2-examples"},{"type":"function","title":"Toolshed.top/1","doc":"Interactively show the top Elixir processes\n\nThis is intended to be called from the IEx prompt and will periodically\nupdate the console with the top processes. Press enter to exit.\n\nOptions:\n\n* `:order` - the sort order for the results (`:reductions`, `:delta_reductions`,\n  `:mailbox`, `:delta_mailbox`, `:total_heap_size`, `:delta_total_heap_size`, `:heap_size`,\n  `:delta_heap_size`, `:stack_size`, `:delta_stack_size`)","ref":"Toolshed.html#top/1"},{"type":"function","title":"Toolshed.tree/1","doc":"Print out directories and files in tree form.","ref":"Toolshed.html#tree/1"},{"type":"function","title":"Toolshed.uname/0","doc":"Print out information about the running software\n\nThis is similar to the Linux `uname` to help people remember what to type.","ref":"Toolshed.html#uname/0"},{"type":"function","title":"Toolshed.uptime/0","doc":"Print out the current uptime.","ref":"Toolshed.html#uptime/0"},{"type":"function","title":"Toolshed.weather/0","doc":"Display the local weather\n\nSee http://wttr.in/:help for more information.","ref":"Toolshed.html#weather/0"},{"type":"extras","title":"Toolshed","doc":"# Toolshed\n\n[![Hex version](https://img.shields.io/hexpm/v/toolshed.svg \"Hex version\")](https://hex.pm/packages/toolshed)\n[![API docs](https://img.shields.io/hexpm/v/toolshed.svg?label=hexdocs \"API docs\")](https://hexdocs.pm/toolshed/Toolshed.html)\n[![CircleCI](https://circleci.com/gh/elixir-toolshed/toolshed.svg?style=svg)](https://circleci.com/gh/elixir-toolshed/toolshed)\n[![REUSE status](https://api.reuse.software/badge/github.com/elixir-toolshed/toolshed)](https://api.reuse.software/info/github.com/elixir-toolshed/toolshed)\n\nToolshed improves the Elixir shell experience by adding a number of IEx helpers.\nThis helps when a normal Unix shell prompt isn't easily accessible like on\n[Nerves](https://nerves-project.org). It doesn't require Nerves, though, and all\nNerves-specific commands aren't even compiled if you're not using it.\n\nHere's a sample list of helpers:\n\n* `cmd` - run a command and print out the output\n* `ping` and `tcping` - check if a remote host is using ICMP or TCP\n* `ifconfig` - list network interfaces\n* `weather` - get the current weather from [wttr.in](https://wttr.in/)\n* `speed_test` - run a simple speed test to guage network throughput\n* `top` - get a list of the top processes and their OTP applications based on\n  CPU and memory\n* `tree` - list directory contents as a tree\n* `lsusb` - list USB devices\n\nTo get a complete list:\n\n```elixir\niex> h Toolshed\n```\n\nTo try it out, add this project to your deps:\n\n```elixir\ndef deps do\n  [\n    {:toolshed, \"~> 0.2\"}\n  ]\nend\n```\n\nRebuild and run in whatever way you prefer. At the IEx prompt, run:\n\n```elixir\niex> use Toolshed\nToolshed imported. Run h(Toolshed) for more info.\n:ok\n\niex> cmd(\"echo hello world\")\nhello world\n0\n\niex> ping \"nerves-project.org\"\nPress enter to stop\nResponse from nerves-project.org (185.199.108.153): time=4.155ms\nResponse from nerves-project.org (185.199.108.153): time=10.385ms\nResponse from nerves-project.org (185.199.108.153): time=12.458ms\n\niex> top\nOTP Application  Name or PID               Reds/Δ      Mbox/Δ     Total/Δ      Heap/Δ     Stack/Δ\nnerves_runtime   Nerves.Runtime.Kernel.UE   72M/10M     157/-32    384K/-4642  192K/73K      86/52\nsystem_registry  SystemRegistry.Global      41M/6134K     0/0      694K/192K   192K/0        35/-11\nsystem_registry  SystemRegistry.Processor   61M/6075K     0/0       73K/-1215   73K/0        10/0\nsystem_registry  SystemRegistry.Registrat 1623K/293K      1/1      211K/109K    73K/0        10/0\nsystem_registry  SystemRegistry.Processor  790K/197K     59/3     1011K/4461   502K/0        38/0\nundefined        #PID<0.1793.0>            221K/68K       0/0       21K/0      6772/0       504/0\nsystem_registry  SystemRegistry.Processor  382K/58K       0/0       16K/-1227  4185/-1354    22/0\nssh              #PID<0.1786.0>            133K/52K       0/0      4184/1599   2586/1599     10/0\nnerves_init_gadg #PID<0.1432.0>            213K/39K       0/0      192K/101K    73K/0        10/0\n```\n\nWhen you get tired of typing `use Toolshed`, add it to your\n[`.iex.exs`](https://hexdocs.pm/iex/IEx.html#module-the-iex-exs-file).","ref":"readme.html"},{"type":"extras","title":"FAQ - Toolshed","doc":"","ref":"readme.html#faq"},{"type":"extras","title":"I have some IEx helpers. Would you consider adding them? - Toolshed","doc":"Based on using and maintaining Toolshed the past several years, here's what ends\nup working best:\n\n1. Wrappers for OTP functions that make them easier to remember or format their\n   output nicer for interactive use\n2. Simple implementations of shell commands that have strong muscle memory for\n   Linux users\n3. Shortcuts to Linux system features (e.g., things that read `/sys` or `/proc`)\n\nThis project is not a Busybox replacement project or an effort to replicate all\nof the functionality in shell commands. Erlang/OTP contains an awful lot of\nbuilt-in functionality. It's not identical to that provided by shell commands,\nbut if there's an easy way to get at it in an IEx helper, that's what we'd like\nto do.","ref":"readme.html#i-have-some-iex-helpers-would-you-consider-adding-them"},{"type":"extras","title":"A lot of these look like Unix commands? Why not run a proper shell? - Toolshed","doc":"Yeah, I miss many Unix commands when I'm at the IEx prompt. Switching to a shell\nis easy on my laptop, but on Nerves devices, it's a pain. Getting a shell prompt\non Nerves is possible, but it's limited due to Nerves not containing a full set\nof commands and it having to be run through Erlang's job control.","ref":"readme.html#a-lot-of-these-look-like-unix-commands-why-not-run-a-proper-shell"},{"type":"extras","title":"Why is everything compiled to toolshed.beam? - Toolshed","doc":"When using Toolshed, the helpers are all imported into the IEx shell context for\nease of use. It looks like they're all defined in the `Toolshed` module. In\nfact, if you don't `import Toolshed` (or `use Toolshed`), you can still access\nthe helpers by calling `Toolshed.helper()`. The problem defining all of the\nhelpers in one module is that it makes `toolshed.ex` very hard to maintain.\n\nWe've experimented with many ways of maintaining the helpers, like using\n`defdelegate` and importing all of the helpers into `toolshed.ex`. There were\nseveral problems with these ways including function docs not being in the\nexpected place, code being duplicated, and manual steps. The most annoying issue\nwas that keeping helpers in lots of `.beam` files had an impact on load time on\nNerves devices. The load-time issue is being addressed in OTP 26 more\ngenerally.\n\nThe end result is that we finally settled on merging all of the helpers at\ncompile-time. The downside to this is that line numbers are wrong in stack\ntraces. Given the history of this issue, this seemed like a good compromise.","ref":"readme.html#why-is-everything-compiled-to-toolshed-beam"},{"type":"extras","title":"You can do so much more with some of these helpers - Toolshed","doc":"Definitely. There's so much that I'd like to explore, but time gets in the way.\nI'm not sold on many decisions that I made, but something was better than\nnothing. Please help me improve this or make your own IEx helpers library. I'm\nquite happy to use it too or pull it in as a dependency.","ref":"readme.html#you-can-do-so-much-more-with-some-of-these-helpers"},{"type":"extras","title":"I want to use one of the functions in my program. Is the API stable? - Toolshed","doc":"This isn't a normal hex.pm library. Use it for the helpers. If you want\nsome code, copy and paste it or incorporate it into a library. I'd like the\nflexibility to change the API to improve interactive use.","ref":"readme.html#i-want-to-use-one-of-the-functions-in-my-program-is-the-api-stable"},{"type":"extras","title":"It would be better if you changed the colors - Toolshed","doc":"This also isn't a question, and you've now made me regret naming the project\n`toolshed`. Please file your grievances\n[here](https://github.com/elixir-toolshed/toolshed/pull/5).","ref":"readme.html#it-would-be-better-if-you-changed-the-colors"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.4.2 - Changelog","doc":"* Updates\n  * `cmd` - Fix issue with using `cmd` on ssh connections due to support for\n    non-UTF8 characters being removed. Elixir 1.16 and later make it easy to\n    replace those characters, so filter them before output. Previous Elixir\n    versions keep the old behavior.\n  * Update licensing and copyright for [REUSE](https://reuse.software/)\n    compliance","ref":"changelog.html#v0-4-2"},{"type":"extras","title":"v0.4.1 - Changelog","doc":"* Updates\n  * `geo` - Limit time taken for network requests to get error messages a lot\n    more quickly","ref":"changelog.html#v0-4-1"},{"type":"extras","title":"v0.4.0 - Changelog","doc":"This release officially adds support for Elixir 1.17 and OTP 27. It removes\nsupport for Elixir 1.11 and 1.12 due to new warnings from dependent libraries.\n\n* Updates\n  * `geo` - Print geo-location results and more.\n  * `httpget` - Support binding to an `:ifname` when making requests. Works well\n    on Linux and approximated on other operating systems.\n  * `httpget` - Use IPv6 if available and fall back to IPv4.","ref":"changelog.html#v0-4-0"},{"type":"extras","title":"v0.3.2 - Changelog","doc":"* Updates\n  * `log_attach` - Use the Erlang logger with OTP 26 and later.  This enables\n    more options and removes a dependency on the now deprecated Elixir console\n    logger. The Elixir logger is still used with OTP 25 and earlier.\n  * `log_attach` - Update config options when re-attaching rather than returning\n    an error.\n  * Fixed Elixir 1.17 warnings","ref":"changelog.html#v0-3-2"},{"type":"extras","title":"v0.3.1 - Changelog","doc":"* Updates\n  * `speed_test` - Added new helper for running a quick network speed test by\n    downloading a large file from a CDN. It automatically stops after a timeout\n    or max number of bytes so that it can be used on metered connections.","ref":"changelog.html#v0-3-1"},{"type":"extras","title":"v0.3.0 - Changelog","doc":"This is a major update in how the Toolshed source code gets compiled. If you are\ncalling any Toolshed functions in your programs, you may need to update the\ncalls. All enabled functions get compiled to be in the Toolshed module now.\n\n* Backwards-incompatible updates\n  * Removed file path completion. This was improved and added to Elixir 1.13.0\n    in December, 2021.\n  * Moved all helper functions to `Toolshed`. They are no longer accessible in\n    other modules. This should go unnoticed if you're using Toolshed at the IEx\n    prompt.\n\n* Improvements\n  * `ping` - Changed `ping` command to use Erlang's relatively new support for\n    sending ICMP echo requests. Previously `ping` made TCP connection requests.\n    The old way is now available via the `tcping` helper. Thanks to @amclain for\n    the ICMP update.\n  * `ping` - `ping` and `tcping` repeat 3 times by default instead of repeating\n    forever.  The new `:count` option can be used to repeat more.\n  * `inspect_bits` - Added `inspect_bits` helper to easily print a number in\n    multiple bases. It also handles negative numbers and gives hex and binary\n    representations that are more familiar to those coming from languages with\n    fixed size integers.\n  * (Nerves-only) `poweroff` -Added helper to gracefully power off Nerves\n    devices that support it.\n  * `httpget` - Increased the timeout for downloads and added `:timeout` option\n    to change it at runtime.\n  * Nerves helpers are completely compiled out when not using Nerves. This can\n    be extended to remove or selectively enable helpers in the future.\n\nThanks to @mnishiguchi for making Toolshed significantly easier to maintain by\nimproving the code organization and adding tests.","ref":"changelog.html#v0-3-0"},{"type":"extras","title":"v0.2.26 - Changelog","doc":"* Improvements\n  * Update `weather` to give a helpful error if the `:ssl` application isn't\n    included in the release.","ref":"changelog.html#v0-2-26"},{"type":"extras","title":"v0.2.25 - Changelog","doc":"* Improvements\n  * Remove path completion when using Elixir 1.13. Path completion was improved\n    and merged into Elixir, so you no longer need Toolshed to use it. The\n    function call to use it is now a no-op on Elixir 1.13. On previous Elixir\n    versions, it will add path completion so there's no need to change any code.","ref":"changelog.html#v0-2-25"},{"type":"extras","title":"v0.2.24 - Changelog","doc":"* Improvements\n  * Add `:port` option to `ping`. Ping also prints out the port number so it's\n    more obvious that 1. TCP \"pings\" are being used and 2. which port was used.","ref":"changelog.html#v0-2-24"},{"type":"extras","title":"v0.2.23 - Changelog","doc":"* New features\n  * Added the `history` command. See what you typed.\n\n* Bug fixes\n  * `fw_validate` calls `Nerves.Runtime.validate_firmware` rather than\n    validating firmware itself.","ref":"changelog.html#v0-2-23"},{"type":"extras","title":"v0.2.22 - Changelog","doc":"* Bug fixes\n  * top: fix flashing that was happening when top was automatically updating","ref":"changelog.html#v0-2-22"},{"type":"extras","title":"v0.2.21 - Changelog","doc":"* New features\n  * The ping command now supports IPv6 addresses. Thanks to Alex McLain for this\n    improvement.\n  * The top command automatically refreshes now.","ref":"changelog.html#v0-2-21"},{"type":"extras","title":"v0.2.20 - Changelog","doc":"* New features\n  * Add `log_attach` and `log_detach` convenience functions for directing log\n    messages to the current IEx session. These provide a simple way for seeing\n    log messages when you either aren't on the same console as the console logger or\n    you don't want to enable the console logger since it messes up the prompt.","ref":"changelog.html#v0-2-20"},{"type":"extras","title":"v0.2.19 - Changelog","doc":"* Bug fixes\n  * `cmd/1` won't crash if the command being run returns non-UTF8 data\n  * `cat/1` no longer adds an extra newline at the end of its input\n\n* Removed commands\n  * Removed the rarely used `pastebin` command","ref":"changelog.html#v0-2-19"},{"type":"extras","title":"v0.2.18 - Changelog","doc":"* New features\n  * Add `httpget` command for performing HTTP GET requests and printing the\n    response to stdout or saving it to the filesystem. Thanks to Jon Thacker for\n    this feature.","ref":"changelog.html#v0-2-18"},{"type":"extras","title":"v0.2.17 - Changelog","doc":"* Bug fixes\n  * Don't trigger autocompletion when in a string interpolation.","ref":"changelog.html#v0-2-17"},{"type":"extras","title":"v0.2.16 - Changelog","doc":"* Bug fixes\n  * Fix path completion issues when wildcard characters are in the string to be\n    completed.","ref":"changelog.html#v0-2-16"},{"type":"extras","title":"v0.2.15 - Changelog","doc":"* New features\n  * Add path autocompletion. Try it out by running `use Toolshed` at the IEx\n    prompt. Then type `File.read(\"/e \")` for files in `/etc` or `ls\n    \"li \"` if you have a `lib` directory under your current directory.","ref":"changelog.html#v0-2-15"},{"type":"extras","title":"v0.2.14 - Changelog","doc":"* Bug fixes\n  * Fix warnings when building with Elixir 1.11.","ref":"changelog.html#v0-2-14"},{"type":"extras","title":"v0.2.13 - Changelog","doc":"* Bug fixes\n  * Improve error message when `:inets` isn't available so that it says how to\n    add it to your `mix.exs`.","ref":"changelog.html#v0-2-13"},{"type":"extras","title":"v0.2.12 - Changelog","doc":"* Bug fixes\n  * If help has been stripped, then don't tell the user that it's available.\n\n* New features\n  * Add `multicast_addresses` command for listing multicast addresses being\n    listened to on each network interface. This is helpful if you're debugging\n    lost multicast subscriptions or just seeing what applications are listening\n    on.","ref":"changelog.html#v0-2-12"},{"type":"extras","title":"v0.2.11 - Changelog","doc":"* New features\n  * Add `date` command for quickly checking the current date and time in UTC","ref":"changelog.html#v0-2-11"},{"type":"extras","title":"v0.2.10 - Changelog","doc":"* New features\n  * Validate firmware using nerves_runtime v0.10.0's Nerves.Runtime.KV.put/2\n    function if available","ref":"changelog.html#v0-2-10"},{"type":"extras","title":"v0.2.9 - Changelog","doc":"* New features\n  * Add simple HTTP request shortcuts: `weather`, `qr_encode`, and `pastebin`","ref":"changelog.html#v0-2-9"},{"type":"extras","title":"v0.2.8 - Changelog","doc":"* New features\n  * Add `ping` to ping a remote IP address repeatedly and add some\n    support for setting the interface to use.","ref":"changelog.html#v0-2-8"},{"type":"extras","title":"v0.2.7 - Changelog","doc":"* New features\n  * Add `lsmod` for returning loaded kernel modules on Nerves","ref":"changelog.html#v0-2-7"},{"type":"extras","title":"v0.2.6 - Changelog","doc":"* New features\n  * Add `uname` for getting running firmware information on Nerves","ref":"changelog.html#v0-2-6"},{"type":"extras","title":"v0.2.5 - Changelog","doc":"* New features\n  * Add `lsof`","ref":"changelog.html#v0-2-5"},{"type":"extras","title":"v0.2.4 - Changelog","doc":"* Bug fixes\n  * Fix warning due to missing Nerves.Runtime","ref":"changelog.html#v0-2-4"},{"type":"extras","title":"v0.2.3 - Changelog","doc":"* Bug fixes\n  * Fix `cmd/1` to capture and print stderr as well. This fixes an issue where\n    stderr prints would go somewhere else and you couldn't see them. This\n    affected IEx sessions running over ssh.","ref":"changelog.html#v0-2-3"},{"type":"extras","title":"v0.2.2 - Changelog","doc":"* Bug fixes\n  * Fix ifconfig crash on sit interfaces\n  * Improve printout of unnamed pids with top\n\n* New features\n  * Add `uptime` helper","ref":"changelog.html#v0-2-2"},{"type":"extras","title":"v0.2.1 - Changelog","doc":"* New features\n  * Add `exit` for exiting an IEx session","ref":"changelog.html#v0-2-1"},{"type":"extras","title":"v0.2.0 - Changelog","doc":"* New features\n  * `top` displays deltas by default\n\n* Bug fixes\n  * Fixed inclusion of Nerves utilities on Nerves","ref":"changelog.html#v0-2-0"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"Initial release","ref":"changelog.html#v0-1-0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}